@@ -37,7 +37,7 @@ class dovecot(bind):
     # разделитель названия и значения переменной
     reSeparator = re.compile("\s*=\s*")
 
-    def postXML(self, xmlArea=False):
+    def postXML(self, xmlArea=None):
         """Последующая постобработка XML"""
         # Добавляем перевод строки если его нет в конец области
         if not xmlArea:
