@@ -19,15 +19,15 @@ from os import path, R_OK
 import platform
 import re
 import errno
-from calculate.lib.utils.dracut import Dracut
-from calculate.lib.datavars import Variable, ReadonlyVariable
-from calculate.lib.utils.files import (readFile, process, listDirectory,
+from ..utils.dracut import Dracut
+from ..datavars import Variable, ReadonlyVariable
+from ..utils.files import (readFile, process, listDirectory,
                                        pathJoin)
-from calculate.lib.utils.mount import isMount, Mounts
-from calculate.lib.utils.system import SystemType
-import calculate.lib.utils.device as device
-from calculate.lib.utils.device import loadEfiVars
-from calculate.lib.utils.common import getKernelUid, getValueFromCmdLine, \
+from ..utils.mount import isMount, Mounts
+from ..utils.system import SystemType
+from ..utils import device
+from ..utils.device import loadEfiVars
+from ..utils.common import getKernelUid, getValueFromCmdLine, \
     CmdlineParams
 
 
@@ -112,19 +112,18 @@ class VariableOsMapperRootDev(ReadonlyVariable):
         dev_links = device.udev.get_device_info(
             name=rootdev).get("DEVLINKS", "")
         if dev_links:
-            mapper_name = filter(lambda x: "/dev/mapper" in x,
-                                 dev_links.split())
+            mapper_name = [x for x in dev_links.split() if "/dev/mapper" in x]
             if mapper_name:
                 return mapper_name[0]
         return rootdev
 
 
-class RootType(object):
+class RootType():
     """
     Типы загруженной системы
     """
 
-    class Value(object):
+    class Value():
         HDD = "hdd"
         LiveCD = "livecd"
         USB_HDD = "usb-hdd"
@@ -244,11 +243,9 @@ class VariableOsRootTypeExt(ReadonlyVariable):
                     return RootType.Value.NetBoot
                 return RootType.Value.LiveCD
 
-            id_dict = dict(map(link2pair,
-                               filter(lambda x: path.islink(x),
-                                      map(lambda x: path.join('/dev/disk/by-id',
-                                                              x),
-                                          listDirectory('/dev/disk/by-id')))))
+            id_dict = dict([link2pair(x) for x 
+                in [path.join('/dev/disk/by-id', y) for y 
+                    in listDirectory('/dev/disk/by-id')] if path.islink(x)])
             if "usb-" in id_dict.get(root_dev, ""):
                 return RootType.Value.USB_HDD
         return RootType.Value.HDD
